# fetch-the-specs

**A command-line tool to report system information in a colorful format.**

## Installation
You can install **fetch-the-specs** using `pip`:

```sh
pip install fetch-the-specs
```

## Usage
To display system information, run the following command:

```sh
fetch-the-specs
```

## License
This project is licensed under the MIT License.